// src/utils/toDisplayString.ts
var isString = (val) => typeof val === "string";
var isSymbol = (val) => typeof val === "symbol";
var isFunction = (val) => typeof val === "function";
var isArray = Array.isArray;
var isMap = (val) => val instanceof Map;
var isSet = (val) => val instanceof Set;
var isObject = (val) => val !== null && typeof val === "object";
var objectToString = Object.prototype.toString;
var isPlainObject = (val) => objectToString.call(val) === "[object Object]";
var isRef = (val) => {
  return !!(val && val.__v_isRef === true);
};
var toDisplayString = (val) => {
  return isString(val) ? val : val == null ? "" : isArray(val) || isObject(val) && (val.toString === objectToString || !isFunction(val.toString)) ? isRef(val) ? toDisplayString(val.value) : JSON.stringify(val, replacer, 2) : String(val);
};
var replacer = (_key, val) => {
  if (isRef(val)) {
    return replacer(_key, val.value);
  } else if (isMap(val)) {
    return {
      [`Map(${val.size})`]: [...val.entries()].reduce(
        (entries, [key, val2], i) => {
          entries[stringifySymbol(key, i) + " =>"] = val2;
          return entries;
        },
        {}
      )
    };
  } else if (isSet(val)) {
    return {
      [`Set(${val.size})`]: [...val.values()].map((v) => stringifySymbol(v))
    };
  } else if (isSymbol(val)) {
    return stringifySymbol(val);
  } else if (isObject(val) && !isArray(val) && !isPlainObject(val)) {
    return String(val);
  }
  return val;
};
var stringifySymbol = (v, i = "") => isSymbol(v) ? `Symbol(${v.description ?? i})` : v;

export { isArray, isFunction, isMap, isObject, isPlainObject, isRef, isSet, isString, isSymbol, objectToString, toDisplayString };
